@@ -21,13 +21,16 @@ class OldHEPData(Parser):
     """
     help = 'Parses OLDHepData format - example OLD HepData input format: http://hepdata.cedar.ac.uk/resource/sample.input'
 
-    options = {
-        'strict': Option('strict', default=True, type=bool, required=False,
-                         help='if specified any additional keywords in OldHEPData file will raise an error'),
-        'use_additional_data': Option('use-additional-data', default=False, type=bool, required=False, variable_mapping='use_additional_data',
-                                      help=('if specified additional data which does not have equivalent in new HEPData format'
-                                            ' will be appended to comment section of the output document'))
-    }
+    @classmethod
+    def options(cls):
+        options = Parser.options()
+        options['strict'] = Option('strict', default=True, type=bool, required=False,
+                                   help='if specified any additional keywords in OldHEPData file will raise an error')
+        options['use_additional_data'] = Option('use-additional-data', default=False, type=bool, required=False, variable_mapping='use_additional_data',
+                                                help=('if specified additional data which does not have equivalent in new HEPData format'
+                                                ' will be appended to comment section of the output document'))
+
+        return options
 
     def reset(self):
         """Clean any processing data, and prepare object for reuse
@@ -115,7 +118,7 @@ class OldHEPData(Parser):
                 for element in self.additional_data[key]:
                     self.data[0]['comment'] += "%s: %s" % (key, element)
 
-        return ParsedData(self.data, self.tables)
+        return ParsedData(self.data[0], self.tables)
 
     def parse(self, data_in):
         # clean any possible data from previous parsing
@@ -178,7 +181,7 @@ class OldHEPData(Parser):
         create new table object and add it to tables collection
         """
         self.set_state('table')
-        self.current_table = HEPTable(index=len(self.tables))
+        self.current_table = HEPTable(index=len(self.tables) + 1)
         self.tables.append(self.current_table)
         self.data.append(self.current_table.metadata)
 
@@ -243,47 +246,48 @@ class OldHEPData(Parser):
                     single_element = data_entry_elements[i]
 
                     if header[i] == 'x': # independent variables
-                        r = re.search('(?P<low>[0-9]+\.?[0-9]*)( +TO +(?P<height>[0-9]+\.?[0-9]*))?', single_element)
+                        r = re.search('(?P<low>[0-9]+\.?[0-9]*)( +TO +(?P<high>[0-9]+\.?[0-9]*))?', single_element)
                         if r:
-                            if r.group('height') is not None:
-                                single_element = {'low': r.group('low'), 'height': r.group('height')}
+                            if r.group('high') is not None:
+                                single_element = {'low': float(r.group('low')), 'high': float(r.group('high'))}
                             else:
-                                single_element = r.group('low')
+                                single_element = {'value': float(r.group('low'))}
                             self.current_table.data['independent_variables'][xy_mapping[i]]['values'].append(single_element)
 
                     elif header[i] == 'y': # independant variable
                         r = re.search('( *)(?P<value>[0-9]+\.?[0-9]*)( *)\+(?P<err_p>[0-9]+\.?[0-9]*),(?P<err_m>\-[0-9]+\.?[0-9]*)( *)\((?P<err_sys>[^()]*)\)', single_element)
                         element = {'errors': []}
                         if r:
-                            element['value'] = r.group('value')
-                            element['errors'] += [{'label': 'stat', 'asymerror': {'plus': r.group('err_p'), 'minus': r.group('err_m')}}]
+                            element['value'] = float(r.group('value'))
+                            element['errors'] += [{'label': 'stat', 'asymerror': {'plus': float(r.group('err_p')), 'minus': float(r.group('err_m'))}}]
 
                         else:
                             r = re.search('( *)(?P<value>[0-9]+\.?[0-9]*)( *)\+-( *)(?P<error>[0-9]+\.?[0-9]*)( *)\((?P<err_sys>[^()]*)\)', single_element)
                             if r:
-                                element['value'] = r.group('value')
-                                element['errors'] += [{'label': 'stat', 'symerror': r.group('error')}]
+                                element['value'] = float(r.group('value'))
+                                element['errors'] += [{'label': 'stat', 'symerror': float(r.group('error'))}]
 
                         err_sys = r.group('err_sys').split('DSYS=')
 
                         for err in err_sys:
                             if not err:
                                 continue
+                            err = err.strip(',')
                             error = {}
                             label = 'sys'
                             r = re.search('^(?P<error>[0-9]+\.?[0-9]*)(\:(?P<label>.*))?,?$', err)
                             if r:
                                 if r.group('label'):
-                                    label += ','+r.group('label')
-                                error = {'symerror': r.group('error') }
+                                    label += ',' + r.group('label')
+                                error = {'symerror': float(r.group('error')) }
 
                             else:
                                 #TODO - check some assumptions - will '+' always be first? and '-' always second?
                                 r = re.search('\+(?P<err_p>[0-9]+\.?[0-9]*)\,(?P<err_m>\-[0-9]+\.?[0-9]*)(\:(?P<label>.*))?', err)
                                 if r:
                                     if r.group('label'):
-                                        label += ','+r.group('label')
-                                    error = {'asymerror': {'plus': r.group('err_p'), 'minus': r.group('err_m')}}
+                                        label += ',' + r.group('label')
+                                    error = {'asymerror': {'plus': float(r.group('err_p')), 'minus': float(r.group('err_m'))}}
                             if not r:
                                 # error happened
                                 raise ValueError("Error while parsing data")
@@ -480,7 +484,7 @@ class OldHEPData(Parser):
             if 'record_ids' not in self.data[0]:
                 self.data[0]['record_ids'] = []
 
-            record_id = {key, data}
+            record_id = {'type': key, 'id': int(data)}
 
             if self.data[0]['record_ids'].count(record_id) == 0:
                 self.data[0]['record_ids'].append(record_id)
